# Bazaar Main Document Catalog

The latest version of these documents are available from Bazaar's documentation site, <http://doc.bazaar.canonical.com/>, and more documentation may be linked from <http://wiki.bazaar.canonical.com/Documentation>.

# Core Documentation

- User Guide
- User Reference
- Quick Start Card (PDF, PNG)
- Release Notes
- 2.0 Upgrade Guide

# Tutorials

- Bazaar in five minutes
- A longer tutorial
- Using Bazaar with Launchpad
- Centralized workflow

# Developer Documentation

- Developer Document Catalog — for developers of Bazaar and plugins

# Web links

- Switching Guides — for users moving from another VCS tool
- Migration Guide — for teams migrating history from another VCS tool
- Glossary
- Frequently Asked Questions

# Other Languages

- Spanish Documentation
- Russian Documentation — документация на русском
- Japanese Documentation — 日本語のドキュメント